"""Template tags and filters for FRED objects."""
from typing import Dict, Optional, cast

from django import template

from ..constants import DnskeyAlgorithm, DnskeyFlag, DnskeyProtocol
from ..settings import SECRETARY_SETTINGS

register = template.Library()


@register.filter
def parse_dnskey_algorithm(value: str) -> Optional[DnskeyAlgorithm]:  # type: ignore[valid-type]
    """Return parsed DNSKEY algorithm."""
    try:
        return DnskeyAlgorithm(value)  # type: ignore[operator, no-any-return]
    except ValueError:
        return None


@register.filter
def parse_dnskey_flags(value: str) -> Optional[DnskeyFlag]:  # type: ignore[valid-type]
    """Return parsed DNSKEY flags."""
    try:
        return DnskeyFlag(value)  # type: ignore[operator, no-any-return]
    except ValueError:
        return None


@register.filter
def parse_dnskey_protocol(value: str) -> Optional[DnskeyProtocol]:  # type: ignore[valid-type]
    """Return parsed DNSKEY algorithm."""
    try:
        return DnskeyProtocol(value)  # type: ignore[operator, no-any-return]
    except ValueError:
        return None


@register.filter
def state_flag_description(value: str) -> str:
    """Return description of the state flag."""
    return cast(Dict[str, str], SECRETARY_SETTINGS.STATE_FLAGS_DESCRIPTIONS).get(value, value)
